/****************************************************************************
 *
 * All portions copyright their respective authors.  All rights reserved.
 *
 * This file is part of IVMan (ivm).
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Troll Tech AS of Norway and appearing in the file
 * LICENSE.QPL included in the packaging of this file.
 * 
 * See http://www.troll.no/qpl for QPL licensing information.
 *
 * $Id: dbus_interface.h,v 1.3 2007/01/29 11:52:31 makoenig Exp $
 *****************************************************************************/

// Some useful DBus functions.

#include <dbus/dbus.h>
#include <stdlib.h>

#include "common.h"

void
ivm_check_dbus_error(DBusError * error);

void ivm_dbus_init();

void *ivm_dbus_reinit();

DBusHandlerResult ivm_dbus_signal_filter(DBusConnection *connection, DBusMessage *message, void *user_data);

char *ivm_dbus_get_name_owner(const char *name);
